@@ -6,8 +6,8 @@ from . import exceptions
 
 
 class Config:
-    FILENAME = '.serverless.yaml'
-    VERSION = 'V2'
+    FILENAME = 'serverless.yaml'
+    VERSION = 'V3'
 
     def __init__(self):
         self.version = None
